@@ -1,10 +1,11 @@
 import tempfile
-
 import os
-from insider.config import DomainConfig
+
 from insider.port_config import PortConfig
 from insider.service_config import ServiceConfig
 
+from syncloud.insider.config import DomainConfig
+
 
 def temp_file(text=''):
     fd, filename = tempfile.mkstemp()
