@@ -1,14 +1,12 @@
 import unittest
+
 import responses
 from mock import MagicMock
-
 from insider.dns import Dns
-from insider.config import Port, Domain, Service
-
 from insider.port_mapper import PortMapper
-
 from convertible import reformat
 
+from syncloud.insider.config import Port, Domain, Service
 from helpers import get_port_config, get_domain_config, get_service_config
 
 
