@@ -1,13 +1,14 @@
 import logging
 import unittest
-from mock import MagicMock
 
+from mock import MagicMock
 from insider.port_mapper import find_available_port
 from insider.port_mapper import PortMapper
-from insider.config import Port
 
+from syncloud.insider.config import Port
 from helpers import get_port_config
 
+
 logging.basicConfig(level=logging.DEBUG)
 
 
